@@ -2,6 +2,7 @@ import json
 import binascii
 import base64
 import typing
+import decimal
 from numbers import Number
 
 import bizerror
@@ -13,16 +14,35 @@ STRING_ENCODINGS = ["utf-8", "gb18030"]
 def cast_int(value):
     if value is None:
         return None
-    return int(value)
+    if isinstance(value, str):
+        if not value.strip():
+            return None
+    if isinstance(value, int):
+        return value
+    try:
+        return int(value)
+    except Exception:
+        raise bizerror.CastToIntegerFailed()
 
 def cast_float(value):
     if value is None:
         return None
-    return float(value)
+    if isinstance(value, str):
+        if not value.strip():
+            return None
+    if isinstance(value, float):
+        return value
+    try:
+        return float(value)
+    except Exception:
+        raise bizerror.CastToFloatFailed()
 
 def cast_bool(value):
     if value is None:
         return None
+    if isinstance(value, str):
+        if not value.strip():
+            return None
     if isinstance(value, bool):
         return value
     if isinstance(value, str):
@@ -43,6 +63,9 @@ def cast_bool(value):
 def cast_list(value):
     if value is None:
         return None
+    if isinstance(value, str):
+        if not value.strip():
+            return None
     if isinstance(value, (list, tuple, set)):
         return list(value)
     if isinstance(value, str):
@@ -61,6 +84,9 @@ def cast_list(value):
 def cast_bytes(value):
     if value is None:
         return None
+    if isinstance(value, str):
+        if not value.strip():
+            return None
     if isinstance(value, bytes):
         return value
     if isinstance(value, str):
@@ -94,6 +120,9 @@ def cast_str(value):
 def cast_dict(value):
     if value is None:
         return None
+    if isinstance(value, str):
+        if not value.strip():
+            return None
     if isinstance(value, dict):
         return value
     if isinstance(value, str):
@@ -106,6 +135,9 @@ def cast_dict(value):
 def cast_numeric(value):
     if value is None:
         return None
+    if isinstance(value, str):
+        if not value.strip():
+            return None
     if isinstance(value, Number):
         return value
     if isinstance(value, bytes):
